#

##

###

###

    	on chain moves
    		# petitions

    	summary

    	objectives ranked

    	possibilities

    		[ ] each ask could have a number associated with
    			it, where duplicates aren't allowed.

    		[
    			{
    				"petition": "send praise to escrow"
    			},
    			{
    				"petition": "receive praise from escrow"
    			},
    			{
    				"petition": "picker remove"
    			},
    			{
    				"petition": "picker add"
    			}
    		]